VerifierSubclaim

Struct VerifierSubclaim 

pub struct VerifierSubclaim<F: PrimeField> {
    pub evaluation_point: Vec<F>,
    pub up_evals: Vec<F>,
    pub down_evals: Vec<F>,
}
The claim that is left to be proven after the combined polynomial resolver verifier has succeeded. It is several evaluation claims about the trace columns and the shifted trace columns at the same evaluation point.

Fields

evaluation_point: Vec<F>

Evaluation point for the claims.

up_evals: Vec<F>

Evaluation claims about the trace columns.

down_evals: Vec<F>

Evaluation claims about the shifted trace columns.