pub struct Proof<F: PrimeField> {
pub up_evals: Vec<F>,
pub down_evals: Vec<F>,
}Expand description
The proof type of the combined polynomial resolver subprotocol.
Note: the sumcheck proof now lives at the protocol
level as part of MultiDegreeSumcheckProof.
Fields
up_evals: Vec<F>The evaluation of the projected trace columns MLEs at the shared point.
down_evals: Vec<F>The evaluations of the shifted projected trace columns MLEs at the shared point.
Implementations
Sourceimpl<F: PrimeField> Proof<F>
impl<F: PrimeField> Proof<F>
Sourcepub fn validate_evaluation_sizes(
&self,
num_cols: usize,
num_down_cols: usize,
) -> Result<(), CombinedPolyResolverError<F>>
pub fn validate_evaluation_sizes( &self, num_cols: usize, num_down_cols: usize, ) -> Result<(), CombinedPolyResolverError<F>>
Check if up_evals and down_evals vectors have the expected lengths.